@@ -32,10 +32,14 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.factory.AccessLock;
 import com.clustercontrol.bean.FacilityConstant;
+import com.clustercontrol.bean.FacilityTreeItem;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.bean.FacilityTreeAttributeConstant;
 import com.clustercontrol.repository.bean.TopicConstant;
+import com.clustercontrol.repository.dao.FacilityDAOImpl;
+import com.clustercontrol.repository.dao.FacilityTreeDAOImpl;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoLocal;
 import com.clustercontrol.repository.ejb.entity.DeviceInfoUtil;
 import com.clustercontrol.repository.ejb.entity.FacilityLocal;
@@ -110,7 +114,8 @@ public class ModifyFacility {
 					(String)facilityId.get(0), 
 					FacilityConstant.TYPE_SCOPE, 
 					parentFacilityId,
-					new Integer(DEFAULT_SORT_ORDER)
+					new Integer(DEFAULT_SORT_ORDER), 
+					new Boolean(false)
 					);
 			
 			
@@ -200,7 +205,7 @@ public class ModifyFacility {
 	 * @throws NamingException
 	 * @throws CreateException
 	 */
-	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException  {
+	public void assignNodeScope(String parentFacilityId, String[] facilityIds) throws NamingException, CreateException, FinderException {
     	//アクセスロック
     	AccessLock.lock(AccessLock.REPOSITORY);
     	
@@ -211,10 +216,16 @@ public class ModifyFacility {
 			    facilityId = facilityIds[i];
 			    //FIXME　ソートの順番はとりあえずオンコードで100+100とする。
 			    //ソート順でスコープよりも後にするため
+			    
+			    FacilityLocal facility = FacilityUtil.getLocalHome().findByFacilityId(facilityId);
+			    Boolean valid = facility.getValid();
 			    FacilityTreeLocal facilityTree = 
 			        FacilityTreeUtil.getLocalHome().create(
-			                facilityId, FacilityConstant.TYPE_NODE, 
-			                parentFacilityId,new Integer(DEFAULT_SORT_ORDER+100));
+			                facilityId, 
+			                FacilityConstant.TYPE_NODE, 
+			                parentFacilityId, 
+			                new Integer(DEFAULT_SORT_ORDER+100), 
+			                valid);
 			}
 			
 			try {
@@ -231,8 +242,17 @@ public class ModifyFacility {
             
             m_log.debug("assignNodeScope() : " + e.getMessage());
 			throw e;
+			
+		} catch (FinderException e) {
+            AplLogger apllog = new AplLogger("REP", "rep");
+            String[] args = {facilityId, parentFacilityId};
+            apllog.put("SYS", "015", args);
+            
+            m_log.debug("assignNodeScope() : " + e.getMessage());
+            throw e;
 		}
 	}
+		
 	
 	/**
 	 * ノード追加
@@ -284,6 +304,9 @@ public class ModifyFacility {
 			//説明を取得し、Facilityに設定
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.DESCRIPTION);
 			facility.setDescription(checkString(values.get(0)));
+			//有効/無効を取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VALID);
+			facility.setValid((Boolean)values.get(0));
 			//DHCPクライアントを取得し、Facilityに設定
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.DHCP_CLIENT);
 			facility.setDhcpClient((Boolean)values.get(0));
@@ -350,6 +373,47 @@ public class ModifyFacility {
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_VERSION);
 			facility.setSnmpVersion(checkString(values.get(0)));
 			
+			//SNMPタイムアウト
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPTIMEOUT);
+			facility.setSnmpTimeout(checkInteger(values.get(0)));
+			
+			//SNMPリトライ回数
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPRETRIES);
+			facility.setSnmpRetries(checkInteger(values.get(0)));
+						
+			//SNMPプロキシ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPPROXY);
+			facility.setSnmpProxy(checkString(values.get(0)));
+			
+			//備考
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.NOTE);
+			facility.setNote(checkArrayList(values));
+			
+			//画面アイコンイメージ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.ICONIMAGE);
+			facility.setIconImage(checkString(values.get(0)));
+			
+			//仮想化ノード種別
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTNODETYPE);
+			facility.setVirtNodeType(checkString(values.get(0)));
+			
+			//仮想マシン管理ノード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMMANAGEMENTNODE);
+			facility.setVMManagementNode(checkString(values.get(0)));
+			
+			//仮想マシンINDEX
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMINDEX);
+			facility.setVmIndex(checkInteger(values.get(0)));
+			
+			//仮想マシン名
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMNAME);
+			facility.setVmName(checkString(values.get(0)));
+			
+			//仮想化ソリューション
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTSOLUTION);
+			facility.setVirtSolution(checkString(values.get(0)));
+			
+			
 //			FIXME　ソートの順番はとりあえずオンコードで100とする。
 		
 			facility.setSortValue(new Integer(DEFAULT_SORT_ORDER));
@@ -365,7 +429,7 @@ public class ModifyFacility {
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX);
 				Integer deviceIndex = checkInteger(values.get(0));
 				
-				//デバイスタイプを取得
+				//デバイスタイプを取
 				values = PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE);
 				String deviceType = checkString(values.get(0));
 				
@@ -487,6 +551,9 @@ public class ModifyFacility {
 			//説明を取得し、Facilityに設定
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.DESCRIPTION);
 			facility.setDescription(checkString(values.get(0)));
+			//有効/無効フラグを取得し、Facilityに設定
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VALID);
+			facility.setValid((Boolean)values.get(0));
 			//DHCPクライアントを取得し、Facilityに設定
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.DHCP_CLIENT);
 			facility.setDhcpClient((Boolean)values.get(0));
@@ -557,6 +624,46 @@ public class ModifyFacility {
 			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMP_VERSION);
 			facility.setSnmpVersion(checkString(values.get(0)));
 			
+			//SNMPタイムアウト
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPTIMEOUT);
+			facility.setSnmpTimeout(checkInteger(values.get(0)));
+			
+			//SNMPリトライ回数
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPRETRIES);
+			facility.setSnmpRetries(checkInteger(values.get(0)));
+						
+			//SNMPプロキシ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.SNMPPROXY);
+			facility.setSnmpProxy(checkString(values.get(0)));
+			
+			//備考
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.NOTE);
+			facility.setNote(checkArrayList(values));
+			
+			//画面アイコンイメージ
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.ICONIMAGE);
+			facility.setIconImage(checkString(values.get(0)));
+			
+			//仮想化ノード種別
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTNODETYPE);
+			facility.setVirtNodeType(checkString(values.get(0)));
+			
+			//仮想マシン管理ノード
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMMANAGEMENTNODE);
+			facility.setVMManagementNode(checkString(values.get(0)));
+			
+			//仮想マシンINDEX
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMINDEX);
+			facility.setVmIndex(checkInteger(values.get(0)));
+			
+			//仮想マシン名
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VMNAME);
+			facility.setVmName(checkString(values.get(0)));
+			
+			//仮想化ソリューション
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VIRTSOLUTION);
+			facility.setVirtSolution(checkString(values.get(0)));
+			
 		    //Facilityと関連しているデバイスを削除
 			try {
 				//Facilityと関連しているデバイスを取得
@@ -700,7 +807,6 @@ public class ModifyFacility {
 			throw e;
 		}
 	}
-	
 
 	/**
 	 * ノード変更(一括)
@@ -754,6 +860,10 @@ public class ModifyFacility {
 					values = PropertyUtil.getPropertyValue(property, NodeProperty.DESCRIPTION);
 					if(checkString(values.get(0)) != null)
 					    facility.setDescription(checkString(values.get(0)));
+					//有効/無効を取得し、Facilityに設定
+					values = PropertyUtil.getPropertyValue(property, NodeProperty.VALID);
+					if (values.get(0) != null && values.get(0) instanceof Boolean)
+						facility.setValid((Boolean)values.get(0));
 					//DHCPクライアントを取得し、Facilityに設定
 					values = PropertyUtil.getPropertyValue(property, NodeProperty.DHCP_CLIENT);
 					if(values.get(0) != null && values.get(0) instanceof Boolean)
@@ -844,6 +954,46 @@ public class ModifyFacility {
 					if(checkString(values.get(0)) != null)
 						facility.setSnmpVersion(checkString(values.get(0)));
 					
+					//SNMPタイムアウト
+					values = PropertyUtil.getProperty(property, NodeProperty.SNMPTIMEOUT);
+					facility.setSnmpTimeout(checkInteger(values.get(0)));
+					
+					//SNMPリトライ回数
+					values = PropertyUtil.getProperty(property, NodeProperty.SNMPRETRIES);
+					facility.setSnmpRetries(checkInteger(values.get(0)));
+								
+					//SNMPプロキシ
+					values = PropertyUtil.getProperty(property, NodeProperty.SNMPRETRIES);
+					facility.setSnmpProxy(checkString(values.get(0)));
+					
+					//備考
+					values = PropertyUtil.getProperty(property, NodeProperty.NOTE);
+					facility.setNote(checkArrayList(values));
+					
+					//画面アイコンイメージ
+					values = PropertyUtil.getProperty(property, NodeProperty.ICONIMAGE);
+					facility.setIconImage(checkString(values.get(0)));
+					
+					//仮想化ノード種別
+					values = PropertyUtil.getProperty(property, NodeProperty.VIRTNODETYPE);
+					facility.setVirtNodeType(checkString(values.get(0)));
+					
+					//仮想マシン管理ノード
+					values = PropertyUtil.getProperty(property, NodeProperty.VMMANAGEMENTNODE);
+					facility.setVMManagementNode(checkString(values.get(0)));
+					
+					//仮想マシンINDEX
+					values = PropertyUtil.getProperty(property, NodeProperty.VMINDEX);
+					facility.setVmIndex(checkInteger(values.get(0)));
+					
+					//仮想マシン名
+					values = PropertyUtil.getProperty(property, NodeProperty.VMNAME);
+					facility.setVmName(checkString(values.get(0)));
+					
+					//仮想化ソリューション
+					values = PropertyUtil.getProperty(property, NodeProperty.VIRTSOLUTION);
+					facility.setVirtSolution(checkString(values.get(0)));
+					
 					//デバイスの配列を取得
 					ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
 				    //デバイス名を取得
@@ -988,6 +1138,54 @@ public class ModifyFacility {
 		}
 	}
 	
+	public void modifyFacilityTreeValid(Property property) throws FinderException, NamingException {
+    	//アクセスロック
+    	AccessLock.lock(AccessLock.REPOSITORY);
+  	
+    	String facilityId = null;
+		ArrayList values = null;
+		Date now = new Date();
+		
+		try {
+			//ファシリティIDを取得
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
+			facilityId = (String)values.get(0);
+			
+			//Facilityを検索し取得
+			FacilityLocal facility = FacilityUtil.getLocalHome().findByFacilityId(facilityId);
+			
+			//変更後の有効/無効フラグをPropertyから取得
+			values = PropertyUtil.getPropertyValue(property, NodeProperty.VALID);
+			Boolean postValid = (Boolean)values.get(0);
+
+			//有効/無効フラグが変更後と等しくない、すべてのFacilityTreeを取得
+			Collection collection = FacilityTreeUtil.getLocalHome().findByFacilityId(facilityId, !postValid);
+			Iterator iterator = collection.iterator();
+			
+			//有効/無効フラグを変更
+			while(iterator.hasNext()){
+				FacilityTreeLocal facilitytree = (FacilityTreeLocal)iterator.next();
+				facilitytree.setValid(postValid);
+//				facilitytree = null;
+			}
+
+			try {
+				//Topicに送信
+				SendTopic send = new SendTopic(TopicConstant.TOPIC_NAME_EXECUTE);
+				send.put(new UpdateRepositoryInfo());
+			} catch (Exception e) {
+				m_log.debug("addScope() : 更新情報送信エラー : " + e.getMessage());
+			}
+				
+		} catch (FinderException e) {
+			m_log.error("modifyFacilityTreeValid() : findByFacilityId() failure ", e);
+			throw e;
+		} catch (NamingException e) {
+			m_log.error("modifyFacilityTreeValid() : getLocalHome() failure ", e);
+			throw e;
+ 		}
+		
+	}
 
     /**
      * ノード詳細を設定
@@ -1014,6 +1212,11 @@ public class ModifyFacility {
                 String attribute = (String)attributes.get(FacilityAttributeConstant.DESCRIPTION);
                 facility.setDescription(attribute);
             }
+            if(attributes.get(FacilityAttributeConstant.VALID) != null){
+                //valid取得
+                Boolean attribute = (Boolean)attributes.get(FacilityAttributeConstant.VALID);
+                facility.setValid(attribute);
+            }
             if(attributes.get(FacilityAttributeConstant.AGENTCONTROL) != null){
                 //ccAgentControl取得
                 Boolean attribute = (Boolean)attributes.get(FacilityAttributeConstant.AGENTCONTROL);
@@ -1154,11 +1357,57 @@ public class ModifyFacility {
             	String attribute = (String)attributes.get(FacilityAttributeConstant.SNMPCOMMUNITY);
             	facility.setSnmpCommunity(attribute);
             }
-            if(attributes.get(FacilityAttributeConstant.SNMPVERSION) != null){
-            	//ccSnmpVersion取得
-            	String attribute = (String)attributes.get(FacilityAttributeConstant.SNMPVERSION);
-            	facility.setSnmpVersion(attribute);
+            if(attributes.get(FacilityAttributeConstant.SNMPTIMEOUT) != null){
+            	//ccSnmpTimeout取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.SNMPTIMEOUT);
+            	facility.setSnmpTimeout(attribute);
             }
+            if(attributes.get(FacilityAttributeConstant.SNMPVERSION) != null){
+            	//ccSnmpRetries取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.SNMPRETRIES);
+            	facility.setSnmpRetries(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.SNMPPROXY) != null){
+            	//ccSnmpProxy取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.SNMPPROXY);
+            	facility.setSnmpProxy(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.NOTE) != null){
+            	//ccNote取得
+            	ArrayList attribute = (ArrayList)attributes.get(FacilityAttributeConstant.NOTE);
+            	facility.setNote(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.ICONIMAGE) != null){
+            	//ccIconImage取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.ICONIMAGE);
+            	facility.setIconImage(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VIRTNODETYPE) != null){
+            	//ccVirtNodeType取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VIRTNODETYPE);
+            	facility.setVirtNodeType(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMMANAGEMENTNODE) != null){
+            	//ccVmManagementNode取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMMANAGEMENTNODE);
+            	facility.setVMManagementNode(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMINDEX) != null){
+            	//ccVmIndex取得
+            	Integer attribute = (Integer)attributes.get(FacilityAttributeConstant.VMINDEX);
+            	facility.setVmIndex(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VMNAME) != null){
+            	//ccVmName取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VMNAME);
+            	facility.setVmName(attribute);
+            }
+            if(attributes.get(FacilityAttributeConstant.VIRTSOLUTION) != null){
+            	//ccSnmpVersion取得
+            	String attribute = (String)attributes.get(FacilityAttributeConstant.VIRTSOLUTION);
+            	facility.setVirtSolution(attribute);
+            }
+
             
         } catch (FinderException e) {
             m_log.debug("setNodeDetail() : " + e.getMessage());
@@ -1238,4 +1487,5 @@ public class ModifyFacility {
 			return null;
 		}
 	}
+	
 }
