@@ -54,7 +54,7 @@ import com.clustercontrol.sharedtable.TableEntry;
 public class SnmpPollerImpl implements SnmpHandler {
 	protected static Log m_log = LogFactory.getLog(SnmpPollerImpl.class);
 
-	/** IPアドレス */
+	// IPアドレス（ポーリングの度に更新）
 	private String m_ipAddress;
 
 	// 収集のターゲットとなるOID（全てのポーリングが終了するまで値を保持）
@@ -66,28 +66,37 @@ public class SnmpPollerImpl implements SnmpHandler {
 	// 収集を終了するOID（ポーリングの度に更新）
 	private ArrayList<SnmpObjectId> m_stopOids;
 
-	// 取得したデータを格納するテーブル
-	DataTable m_dataTable;
+	// 取得したデータを格納するテーブル（ポーリングの度に更新）
+	private DataTable m_dataTable;
 
-	// メッセージ 
+	// メッセージ（ポーリングの度に更新）
 	private String m_message = null;
 
 	// 待機フラグ
 	private boolean m_waitFlg;
 
-	// 収集したOIDの最後のインデックスをチェックするか否かのフラグ	
+	// 収集したOIDの最後のインデックスをチェックするか否かのフラグ（ポーリングの度に更新）
 	private boolean m_indexCheckFlg = false;
 
-	// m_indexCheckFlg = true の場合にリトライした回数を保持
-	private int m_indexCheckRetryCount = 0;
+	// m_indexCheckFlg = true の場合に、取得したOIDのインデックスが異なることで
+	// リトライした回数を保持（ポーリングの度に更新）
+	private int m_indexCheckDiffIndexRetryCount = 0;
 
+	// m_indexCheckFlg = true の場合に、取得できたVarBindの数が異なることで
+	// リトライした回数を保持（ポーリングの度に更新）
+	private int m_indexCheckVarBindSizeRetryCount = 0;
+	
+	// m_indexCheckFlg = true の場合にリトライした回数の合計を保持（ポーリングの度に更新）
+	private int m_indexCheckRetryCountTotal = 0;
+	
 	// m_indexCheckFlg = true の場合にリトライする回数の最大値
-	private final int m_indexCheckRetryCountMax = 3;
-
+	private final int MAX_RETRY_COUNT = 10;
+	
 	// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
 	// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
 	//  プロセスのリストを最後まで取得できない場合があることへの対処）
 	// そのために最後のOIDでリトライ処理をするその回数を保持
+	// （ポーリングの度に更新）
 	private int m_indexCheckLastIndexRetryCount = 0;
 
 	// 最期にポーリングを行なった際のOIDのリスト m_indexCheckFlg = true の場合に使用する
@@ -97,9 +106,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 	private boolean m_retryFlg = false;
 
 	// 全体的なポーリングのリトライ回数
-	private int m_retryCount = 1;
+	private final int m_retryCount = 1;
 
-	// エラーコード
+	// エラーコード（ポーリングの度に更新）
 	private int m_errorCode = 0;
 
 	// エラーコード
@@ -109,7 +118,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 	// クラス変数の初期化
 	private void init(){
-		m_indexCheckRetryCount = 0;
+		m_indexCheckDiffIndexRetryCount = 0;
+		m_indexCheckVarBindSizeRetryCount = 0;
+		m_indexCheckRetryCountTotal = 0;
 		m_indexCheckLastIndexRetryCount = 0;
 		m_errorCode = Normal;
 		m_message = null;
@@ -239,6 +250,9 @@ public class SnmpPollerImpl implements SnmpHandler {
 				if(m_retryFlg == false){
 					//　リトライしない
 					break;
+				} else {
+					// 一旦取得した全てのデータを削除してリトライ
+					m_dataTable.clear();
 				}
 			}
 		} catch (InterruptedException e) {
@@ -269,8 +283,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 		}
 
+		// リトライ回数が多い場合は出力する
+		if(m_indexCheckRetryCountTotal >= 100){
+			m_log.warn("polling():" + m_ipAddress + 
+					" too many retries. count : " + m_indexCheckRetryCountTotal);
+		}
+		
 		// デバッグ出力
 		if (m_log.isDebugEnabled()) {
+			m_log.debug("polling() " + m_ipAddress + " retry total count : " + m_indexCheckRetryCountTotal);
 			m_log.debug("polling() end :" + ipAddress.toString());
 		}
 	}
@@ -327,14 +348,18 @@ public class SnmpPollerImpl implements SnmpHandler {
 			String lastIndexStr = null;
 
 			// インデックスの最大値を保持する(m_indexCheckFlgがtrueの場合のみ利用)
+			// 取得できたOIDのインデックスに差異がない場合は-lのまま
 			int maxIndex = -1;
 
 			// 次回のポーリングでpduにセットするOIDの開始と終了のOIDを保持する
 			ArrayList<SnmpObjectId> nextStartOids = new ArrayList<SnmpObjectId>(m_startOids.size());
 			ArrayList<SnmpObjectId> nextStopOids = new ArrayList<SnmpObjectId>(m_stopOids.size());
-			// 最期にポーリングを行なった際のOIDのリスト(m_indexCheckFlg = true の場合に使用)
+			// 最期にポーリングを行なった際に取得したOIDのリスト(m_indexCheckFlg = true の場合に使用)
 			ArrayList<String> lastPollingOids = new ArrayList<String>(m_startOids.size());
-
+			// インデックスチェックが必要な場合は、この時点ではテーブルに反映することはできないため、
+			// 一時的にArrayListに保持する(m_indexCheckFlg = true の場合に使用)
+			ArrayList<TableEntry> entryBuffer = new ArrayList<TableEntry>(m_startOids.size());
+			
 			// pduの戻りとして帰ってきた SnmpVarBindを順次処理する
 			int length = pdu.getLength();
 			for (int i = 0; i < length; i++) {
@@ -376,16 +401,13 @@ public class SnmpPollerImpl implements SnmpHandler {
 					}
 					continue;
 				} else {
-					// 取得した値をテーブルに書き込むか否かのチェックフラグ
-					boolean setFlug = true;
-
 					// インデックスチェックフラグが設定されている場合は、OIDの最後のインデックスが
 					// 一致しているか否かをチェックする
 					if (m_indexCheckFlg == true) {
-						if (lastIndexStr == null) {
+						if (lastIndexStr == null) { // ループの1回目（i=0の場合）
 							lastIndexStr = oidString.substring(oidString
 									.lastIndexOf(".")+1);
-						} else {
+						} else { // ループの2回目以降は値が設定されている
 							String indexStr = oidString.substring(oidString
 									.lastIndexOf(".")+1);
 
@@ -395,59 +417,56 @@ public class SnmpPollerImpl implements SnmpHandler {
 										+ ", " + lastIndexStr + ", "
 										+ oidString);
 
-//								// 格納されたMIB値を削除します。
-//								for(int j=0; j <= i; j++){
-//								String removeOid = pdu.getVarBindAt(j).getName().toString();
-//								m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-//								m_dataTable.removeValue(removeOid);
-//								}
-
 								// 最大のインデックスを設定
 								int lastIndex = Integer.parseInt(lastIndexStr);
 								if(lastIndex > maxIndex){
 									maxIndex = lastIndex;
 								}
-
-								// 取得値をテーブルに書き込まないように設定
-								setFlug = false;
 							}
 							lastIndexStr = indexStr;
 						}
 					}
 
-					if (setFlug == true) {
-						// if (var.getValue() instanceof SnmpNoSuchInstance) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof
-						// SnmpNoSuchObject) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof SnmpV2Error) {
-						// // 何もしない
-						// } else if (var.getValue() instanceof SnmpNull) {
-						// // 何もしない
-						// } else
-						
-						// デバッグ
-						if (m_log.isDebugEnabled()) {
-							m_log.debug("set " + m_ipAddress + ","
-									+ oidString + "," + time + ","
-									+ var.getValue().toString() + ", "
-									+ var.getValue());
+					// デバッグ
+					if (m_log.isDebugEnabled()) {
+						m_log.debug("set " + m_ipAddress + ","
+								+ oidString + "," + time + ","
+								+ var.getValue().toString() + ", "
+								+ var.getValue());
+					}
+					
+					if (var.getValue() instanceof SnmpUInt32) {
+						long longValue = ((SnmpUInt32)var.getValue()).getValue();
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new TableEntry(oidString, time, longValue));
+						} else {
+							m_dataTable.putValue(oidString, time, longValue);
 						}
-
-						if (var.getValue() instanceof SnmpUInt32) {
-							long longValue = ((SnmpUInt32)var.getValue()).getValue();
+					} else if (var.getValue() instanceof SnmpInt32) {
+						long longValue = ((SnmpInt32)var.getValue()).getValue();
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new TableEntry(oidString, time, longValue));
+						} else {
 							m_dataTable.putValue(oidString, time, longValue);
-						} else if (var.getValue() instanceof SnmpInt32) {
-							long longValue = ((SnmpInt32)var.getValue()).getValue();
+						}
+					} else if (var.getValue() instanceof SnmpCounter64) {
+						BigInteger bigInt = ((SnmpCounter64)var.getValue()).getValue();
+						// BigInteger が大き過ぎて long に適さない場合は、下位の 64 ビットだけが返される。
+						long longValue = bigInt.longValue();
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new TableEntry(oidString, time, longValue));
+						} else {
 							m_dataTable.putValue(oidString, time, longValue);
-						} else if (var.getValue() instanceof SnmpCounter64) {
-							BigInteger bigInt = ((SnmpCounter64)var.getValue()).getValue();
-							// BigInteger が大き過ぎて long に適さない場合は、下位の 64 ビットだけが返される。
-							long longValue = bigInt.longValue();
-							m_dataTable.putValue(oidString, time, longValue);
-						} else if (var.getValue() instanceof SnmpOctetString) {
+						}
+					} else if (var.getValue() instanceof SnmpOctetString) {
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new TableEntry(oidString, time, var.getValue().toString()));
+						} else {
 							m_dataTable.putValue(oidString, time, var.getValue().toString());
+						}
+					} else {
+						if(m_indexCheckFlg == true){
+							entryBuffer.add(new TableEntry(oidString, time, var.getValue()));
 						} else {
 							m_dataTable.putValue(oidString, time, var.getValue());
 						}
@@ -457,7 +476,7 @@ public class SnmpPollerImpl implements SnmpHandler {
 					nextStartOids.add(m_startOids.get(i));
 					nextStopOids.add(m_stopOids.get(i));
 					nxt.addVarBind(new SnmpVarBind(var.getName()));
-					// 最期に実行したポーリングのOIDのリストを保持する
+					// 最期に実行したポーリングで取得したOIDのリストを保持する
 					// m_indexCheckFlg が true の場合のリトライ処理のため
 					lastPollingOids.add(var.getName().toString());
 				}
@@ -465,28 +484,69 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 			// インデックスチェックを行なっている場合
 			if(m_indexCheckFlg == true){
-				// 次に実行するOIDが１つもない場合
-				if (lastPollingOids.size() == 0) {
+				// 正常に値取得できている場合は、値をテーブルに設定する
+				if (maxIndex == -1
+						&& ((lastPollingOids.size() == m_lastPollingOids.size())
+								|| (lastPollingOids.size() == 0))) {
+					// 一時的にArrayListで保持されていた取得値をセットする
+					Iterator<TableEntry> itr = entryBuffer.iterator();
+					while(itr.hasNext()){
+						TableEntry entry = itr.next();
+						
+						// デバッグ
+						if (m_log.isDebugEnabled()) {
+							m_log.debug("set (buffer to table) " + m_ipAddress + ","
+									+ entry.getKey() + "," + time + ","
+									+ entry.getValue().toString() + ", "
+									+ entry.getValue());
+						}
+						
+						m_dataTable.putValue(entry);
+					}
+					
 					// リトライ回数をリセット
-					m_indexCheckRetryCount = 0;
+					m_indexCheckDiffIndexRetryCount = 0;
+					m_indexCheckVarBindSizeRetryCount = 0;
+				} else {
+					m_log.debug("detect error. " + m_ipAddress);
+				}
+
+				// 対応しているエラーパターン（VarBindの数をn個とする）
+				// 1) n個全て取得できているが、対象のMIBツリーの最後ではない
+				// 2) n個全て取得できているが、indexが揃っていない（少なくともどれかのindexが異なる）
+				// 3) n個全ては取得できていない。かつ、indexが揃っていない（少なくともどれかのindexが異なる）
+				// 4) n個全ては取得できていないが、indexは全て同じ
+				if (lastPollingOids.size() == 0) {  // エラーパターン1への対応
+					// 次に実行するOIDが１つもない場合
+					// ポーリング対象のスコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする
+					// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
+					//  プロセスのリストを最後まで取得できない場合があることへの対処）
+					
+					// リトライ回数をリセット
+					m_indexCheckDiffIndexRetryCount = 0;
+					m_indexCheckVarBindSizeRetryCount = 0;
 
 					if (m_indexCheckLastIndexRetryCount >= 1) {
+						// 2回連続で同じOID（同じVarBindのセット）でポーリングの結果、全てのポーリングの戻りの
+						// PDUに入っている「次の問い合わせ対象OID」が取得対象のMIBツリーからはずれているため
 						// 正常に取得できたと判断
 					} else {
+						// ポーリング対処のOIDのリストの全てが同時に終了した場合、
+						// 対象スコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする。
+						// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
+						// プロセスのリストを最後まで取得できない場合があることへの対処）
 						if (m_log.isDebugEnabled()) {
 							m_log.debug("check retry. count="
 									+ m_indexCheckLastIndexRetryCount + " "
 									+ m_ipAddress);
 						}
-
-						// ポーリング対処のOIDのリストの全てが同時に終了した場合、
-						// 対象スコープを抜ける際のOIDが本当にそのスコープの最後のOIDなのかをチェックする。
-						// （Net-SNMPのHOST-RESOURCES-MIBでプロセス情報を取得した際に、
-						// プロセスのリストを最後まで取得できない場合があることへの対処）
+						
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
 						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+
 						for (int i = 0; i < m_lastPollingOids.size(); i++) {
 							if (m_log.isDebugEnabled()) {
 								m_log.debug("retry last polling set VarBind "
@@ -502,84 +562,125 @@ public class SnmpPollerImpl implements SnmpHandler {
 
 						// 最後のOIDでリトライ処理を実行した回数をカウントアップ
 						m_indexCheckLastIndexRetryCount++;
+						m_indexCheckRetryCountTotal++;
 					}
-				} else {
+				} else {  // エラーパターン1以外の対応（正常動作の場合も含む）
+					// 次に実行するOIDが１つ以上ある場合
+
+					// ログ出力
+					if (m_log.isDebugEnabled()) {
+						if (m_indexCheckLastIndexRetryCount != 0) {
+							m_log.debug("detect error." + m_ipAddress);
+						}
+					}
+					
 					// 最後のOIDでリトライ処理を実行した回数をリセット
 					m_indexCheckLastIndexRetryCount = 0;
 
 					// インデックスの異なるものが戻ってきていた場合
-					// もしくは、前回ポーリング実視時と次回ポーリング予定のOIDの数がちがう場合
 					// 再度ポーリングを実行する
-					if (maxIndex > 0	||
-							(lastPollingOids.size() != 0
-									&& lastPollingOids.size() != m_lastPollingOids.size())) {
+					if (maxIndex >= 0){  // エラーパターン2or3の対応
 						// ログ出力
 						if (m_log.isDebugEnabled()){
-							m_log.debug("recovery retry!! " + m_ipAddress);
+							m_log.debug("recovery(index not match) " + m_ipAddress
+									+ "  max index:" + maxIndex
+									+ "  next VarBind size:" + lastPollingOids.size());
 						}
 
-						// ログ出力
-						if(m_log.isDebugEnabled()){
-							if(maxIndex > 0){
-								m_log.debug("recovery(index not match) " + m_ipAddress);
-							} else {
-								m_log.debug("recovery(next count:" + lastPollingOids.size()
-										+ ") " + m_ipAddress);
+//						// 格納されたMIB値を削除します。
+//						for(int j=0; j < pdu.getLength(); j++){
+//							String removeOid = pdu.getVarBindAt(j).getName().toString();
+//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
+//							m_dataTable.removeValue(removeOid);
+//						}
+						
+						nextStartOids.clear();
+						nextStopOids.clear();
+						lastPollingOids.clear();
+						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+
+						if(m_indexCheckDiffIndexRetryCount < MAX_RETRY_COUNT){
+							for (int i = 0; i < m_lastPollingOids.size(); i++) {
+								String lastOid = m_lastPollingOids.get(i);
+								// 最大のインデックスのものがリトライによって収集されるように
+								// maxIndex-lをインデックスに設定する
+								String nextOid = lastOid.substring(0, lastOid.lastIndexOf(".") + 1)
+								+ (maxIndex - 1);
+
+								nextStartOids.add(m_startOids.get(i));
+								nextStopOids.add(m_stopOids.get(i));
+								nxt.addVarBind(new SnmpVarBind(nextOid));
+								lastPollingOids.add(nextOid);
+							
+								// ログ出力
+								if (m_log.isDebugEnabled()) {
+									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
+								}
 							}
+						} else { // リトライ回数の上限を超えた場合
+							m_log.error("too many retries(index not match). " + m_ipAddress 
+									+ " count:" + m_indexCheckDiffIndexRetryCount);
+							// 収集したデータを全てクリアする
+							m_dataTable.clear();
+							
+							// nxtが空となるためポーリングは継続されない
 						}
-
-						// 格納されたMIB値を削除します。
-						for(int j=0; j < pdu.getLength(); j++){
-							String removeOid = pdu.getVarBindAt(j).getName().toString();
-							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
-							m_dataTable.removeValue(removeOid);
+						
+						// リトライ回数をカウントアップ
+						m_indexCheckDiffIndexRetryCount++;
+						m_indexCheckVarBindSizeRetryCount = 0;
+						m_indexCheckRetryCountTotal++;
+					} else if(lastPollingOids.size() != m_lastPollingOids.size()) {  // エラーパターン4の対応
+						// ログ出力
+						if (m_log.isDebugEnabled()){
+							m_log.debug("recovery(next count:" + lastPollingOids.size() + ") "
+									+ m_ipAddress);
 						}
+						
+//						// 格納されたMIB値を削除します。
+//						for(int j=0; j < pdu.getLength(); j++){
+//							String removeOid = pdu.getVarBindAt(j).getName().toString();
+//							m_log.debug("remove " + m_ipAddress + ", " + removeOid);
+//							m_dataTable.removeValue(removeOid);
+//						}
 
 						nextStartOids.clear();
 						nextStopOids.clear();
 						lastPollingOids.clear();
 						nxt = new SnmpPduRequest(SnmpPduPacket.GETNEXT);
-						for (int i = 0; i < m_lastPollingOids.size(); i++) {
-							String nextOid = null;
-							if (m_indexCheckRetryCount < m_indexCheckRetryCountMax) {
-
-								nextOid = m_lastPollingOids.get(i);
-
-								// リトライ回数をカウントアップ
-								m_indexCheckRetryCount++;
-							} else {
-								String lastOid = m_lastPollingOids.get(i);
-								// 最大のインデックスのものがリトライによって収集されるように
-								// maxIndex-lをインデックスに設定する
-								nextOid = lastOid.substring(0,
-										lastOid.lastIndexOf(".") + 1)
-										+ (maxIndex-1);
-
+						nxt.setRequestId(SnmpPduPacket.nextSequence());
+						
+						// 最大リトライ回数（デフォルト3回）までは、同じOIDでリトライ処理
+						// 永遠に同じOIDでリトライ処理が実行されないように、最大リトライ回数を超えたものは、
+						// IF文分岐の下のロジックを通る
+						if(m_indexCheckVarBindSizeRetryCount < MAX_RETRY_COUNT){
+							for (int i = 0; i < m_lastPollingOids.size(); i++) {
+								String nextOid = m_lastPollingOids.get(i);
 
+								nextStartOids.add(m_startOids.get(i));
+								nextStopOids.add(m_stopOids.get(i));
+								nxt.addVarBind(new SnmpVarBind(nextOid));
+								lastPollingOids.add(nextOid);
+							
 								// ログ出力
-								if(m_log.isDebugEnabled()){
-									if(m_indexCheckLastIndexRetryCount != 0){
-										m_log.debug("recovery miss!!" + m_ipAddress);
-									}
+								if (m_log.isDebugEnabled()) {
+									m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
 								}
-
-								// リトライ回数をリセット
-								m_indexCheckRetryCount = 0;
 							}
-
-							// ログ出力
-							if(m_log.isDebugEnabled()){
-								m_log.debug("set VarBind " + m_ipAddress + "," + nextOid);
-							}
-
-							nextStartOids.add(m_startOids.get(i));
-							nextStopOids.add(m_stopOids.get(i));
-							nxt.addVarBind(new SnmpVarBind(nextOid));
-							lastPollingOids.add(nextOid);
+						} else { // リトライ回数の上限を超えた場合
+							m_log.error("too many retries(VarBind size not match). " + m_ipAddress 
+									+ " count:" + m_indexCheckVarBindSizeRetryCount);
+							// 収集したデータを全てクリアする
+							m_dataTable.clear();
+							
+							// nxtが空となるためポーリングは継続されない
 						}
-					} else {
-						// リトライ回数をリセット
-						m_indexCheckRetryCount = 0;
+							
+						// リトライ回数をカウントアップ
+						m_indexCheckDiffIndexRetryCount = 0;
+						m_indexCheckVarBindSizeRetryCount++;
+						m_indexCheckRetryCountTotal++;
 					}
 				}
 			}
@@ -594,11 +695,15 @@ public class SnmpPollerImpl implements SnmpHandler {
 				synchronized (session) {
 					session.notify();
 				}
+				
 				return;
 			}
 		} catch (Exception e) { // 何か例外が生じた場合は収集を停止する
 			m_log.error("InternalError ", e);
 
+			// 収集したデータを全てクリアする
+			m_dataTable.clear();
+			
 			// 収集を終了します
 			synchronized (session) {
 				m_errorCode = InternalError;
@@ -654,9 +759,10 @@ public class SnmpPollerImpl implements SnmpHandler {
 			for (int i = 1; i < bind.length; i++) {
 				addMessage = addMessage + "\n\t" + ipAddress + " " + bind[i].getName();
 			}
+			message = message + addMessage;
 		}
 
-		m_log.warn(message + addMessage);
+		m_log.warn(message);
 
 		synchronized (session) {
 			m_errorCode = TimeOutError;
