@@ -531,7 +531,7 @@ public class LogManager extends Thread {
 	 * 全てのTopicとQueueの再接続処理を行う
 	 * 
 	 */
-	synchronized public void reConnection() {
+	public void reConnection() {
 		
 		log.info("SyslogForward reconnect start");
 		
